***********
thermotools
***********

.. image:: https://travis-ci.org/markovmodel/thermotools.svg?branch=devel
   :target: https://travis-ci.org/markovmodel/thermotools
.. image:: https://ci.appveyor.com/api/projects/status/nsahbq5s33n81rco/branch/devel?svg=true
   :target: https://ci.appveyor.com/project/cwehmeyer/thermotools/branch/devel
.. image:: https://badge.fury.io/py/thermotools.svg
   :target: https://pypi.python.org/pypi/thermotools
.. image:: https://img.shields.io/pypi/dm/thermotools.svg
   :target: https://pypi.python.org/pypi/thermotools
.. image:: https://anaconda.org/omnia/thermotools/badges/installer/conda.svg
   :target: https://conda.anaconda.org/omnia
.. image:: https://anaconda.org/omnia/thermotools/badges/downloads.svg
   :target: https://anaconda.org/omnia/thermotools

This Python package provides a lowlevel implementation of (transition-based and histogram)
reweighting analyis methods.


Installation
============

Using conda (recommended)::

   conda install -c omnia thermotools

Using pip from PyPI::

   pip install thermotools

Using pip from github (this will install the latest development version)::

   pip install git+https://github.com/markovmodel/thermotools.git@devel
